@@ -22,15 +22,15 @@ namespace binding {
  */
 template <>
 std::shared_ptr<t_ctx0>
-make_context(std::shared_ptr<Table> table, const t_schema& schema, std::shared_ptr<t_view_config> view_config, const std::string& name);
+make_context(std::shared_ptr<Table> table, std::shared_ptr<t_schema> schema, std::shared_ptr<t_view_config> view_config, const std::string& name);
 
 template <>
 std::shared_ptr<t_ctx1>
-make_context(std::shared_ptr<Table> table, const t_schema& schema, std::shared_ptr<t_view_config> view_config, const std::string& name);
+make_context(std::shared_ptr<Table> table, std::shared_ptr<t_schema> schema, std::shared_ptr<t_view_config> view_config, const std::string& name);
 
 template <>
 std::shared_ptr<t_ctx2>
-make_context(std::shared_ptr<Table> table, const t_schema& schema, std::shared_ptr<t_view_config> view_config, const std::string& name);
+make_context(std::shared_ptr<Table> table, std::shared_ptr<t_schema> schema, std::shared_ptr<t_view_config> view_config, const std::string& name);
 
 } //namespace binding
 } //namespace perspective
