@@ -6,6 +6,7 @@
 # the Apache License 2.0.  The full license can be found in the LICENSE file.
 #
 
+from six import string_types
 from datetime import date, datetime
 from .view import View
 from ._accessor import _PerspectiveAccessor
@@ -108,16 +109,18 @@ class Table(object):
     def get_computed_functions(self):
         """Returns a dict of computed function metadata, where each value is a
         dict that contains the following metadata:
-            - name
-            - label
-            - pattern
-            - computed_function_name: the name of the computed function
-            - input_type: the data type of input columns ("float"/"integer" and
-            "date"/"datetime" are interchangable)
-            - return_type: the return type of its output column
-            - group: a category for the function
-            - num_params: the number of input parameters
-            - format_function: an anonymous function used for naming new columns
+
+        - name
+        - label
+        - pattern
+        - computed_function_name: the name of the computed function
+        - input_type: the data type of input columns ("float"/"integer" and
+        "date"/"datetime" are interchangable)
+        - return_type: the return type of its output column
+        - group: a category for the function
+        - num_params: the number of input parameters
+        - format_function: an anonymous function used for naming new columns
+
         """
         computed_functions = get_computed_functions()
         for value in computed_functions.values():
@@ -231,7 +234,7 @@ class Table(object):
         Returns:
             :obj:`bool`: Whether this filter is valid.
         '''
-        if isinstance(filter[1], str):
+        if isinstance(filter[1], string_types):
             filter_op = str_to_filter_op(filter[1])
         else:
             filter_op = filter[1]
@@ -249,7 +252,7 @@ class Table(object):
         schema = self.schema()
         in_schema = schema.get(filter[0], None)
         if in_schema and (schema[filter[0]] == date or schema[filter[0]] == datetime):
-            if isinstance(value, str):
+            if isinstance(value, string_types):
                 value = self._date_validator.parse(value)
 
         return value is not None
@@ -439,7 +442,7 @@ class Table(object):
         if not callable(callback):
             return ValueError(
                 "remove_delete callback should be a callable function!")
-        self._delete_callbacks.remove_callbacks(lambda cb: cb != callback)
+        self._delete_callbacks.remove_callbacks(lambda cb: cb == callback)
 
     def delete(self):
         '''Delete this :class:`~perspective.Table` and clean up associated
@@ -452,7 +455,7 @@ class Table(object):
                 "- call delete() on each view, and try again.")
         self._state_manager.remove_process(self._table.get_id())
         self._table.unregister_gnode(self._gnode_id)
-        [cb() for cb in self._delete_callbacks.get_callbacks()]
+        [cb() for cb in self._delete_callbacks]
 
     def _update_callback(self, port_id):
         """After `process` completes internally, this method is called by the
@@ -464,5 +467,5 @@ class Table(object):
             came from.
         """
         cache = {}
-        for callback in self._callbacks.get_callbacks():
+        for callback in self._callbacks:
             callback["callback"](port_id=port_id, cache=cache)
