@@ -509,7 +509,7 @@ class TestTableArrow(object):
             "a": [1.5, 2.5, np.nan, 3.5, 4.5, np.nan, np.nan, np.nan]
         })
 
-        arrow_table = pa.Table.from_pandas(data)
+        arrow_table = pa.Table.from_pandas(data, preserve_index=False)
 
         assert arrow_table["a"].null_count == 4
 
@@ -518,6 +518,7 @@ class TestTableArrow(object):
         writer = pa.RecordBatchStreamWriter(
             stream, arrow_table.schema, use_legacy_format=False)
         writer.write_table(arrow_table)
+        writer.close()
         arrow = stream.getvalue().to_pybytes()
 
         # load
